Method: MIME::Type#content_type
- Defined in:
- lib/mime/type.rb
#content_type ⇒ Object
Returns the whole MIME content-type string.
The content type is a presentation value from the MIME type registry and should not be used for comparison. The case of the content type is preserved, and extension markers (x-) are kept.
text/plain => text/plain
x-chemical/x-pdb => x-chemical/x-pdb
audio/QCELP => audio/QCELP
286 287 288 |
# File 'lib/mime/type.rb', line 286 def content_type @content_type end |